%bcond_without openmpi
%define _openmpi_load module load openmpi
%define _openmpi_unload module unload openmpi

%{!?openmpiversion: %global  openmpiversion 4.1.6}
%global openmpinumversion %( printf "%02d%02d%02d" `echo %{openmpiversion} | cut -d. -f1,2,3 --output-delimiter=" "` )

%global toptopdir /usr/local/%{rname}
%global topdir /usr/local/%{rname}/%{version}
%global toptopdiropenmpi  /usr/local/%{rname}/openmpi-%{openmpiversion}
%global topdiropenmpi  /usr/local/%{rname}/openmpi-%{openmpiversion}/%{version}

%global modulefile_path_top /usr/local/share/Modules/modulefiles/%{rname}

%global __provides_exclude_from ^lib|^pkgconfig
%global __requires_exclude_from ^libgdal|^libptscotch|^libscotch|^libesmumps|^libptesmumps|^libmpi
%filter_from_provides /^lib\|^pkgconfig)/d
%filter_from_requires /^lib(gdal\|ptscotch\|scotch\|esmumps\|ptesmumps\|mpi)/d
%filter_setup

%bcond_with mpich
%bcond_without metis

# This flag prevents internal links
%undefine _ld_as_needed

Version:       7.0.6
%global numversion %(echo %{version} | tr -d .)
Name:          scotch%{numversion}
%global rname  scotch
Summary:       Graph, mesh and hypergraph partitioning library
Release:       1%{?dist}

License:       CeCILL-C
URL:           https://gitlab.inria.fr/scotch/scotch
Source0:       https://gitlab.inria.fr/scotch/scotch/-/archive/v%{version}/scotch-v%{version}.tar.bz2

BuildRequires: bison
BuildRequires: bzip2-devel
BuildRequires: cmake
BuildRequires: flex
BuildRequires: gcc-c++
BuildRequires: gcc-gfortran
BuildRequires: make
BuildRequires: xz-devel
BuildRequires: zlib-devel
Requires: environment-modules-local

%description
Scotch is a software package for graph and mesh/hypergraph partitioning and
sparse matrix ordering. The parallel scotch libraries are packaged in the
ptscotch sub-packages.

%package devel
Summary:       Development libraries for scotch
Requires:      %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains development libraries for scotch.


%if %{with metis}
%package devel-metis
Summary:       Metis compatibility header
Requires:      %{name}-devel%{?_isa} = %{version}-%{release}

%description devel-metis
This header is a drop-in replacement for the original metis.h header
to build against the scotch.
%endif


%package doc
Summary:       Documentations and example for scotch and ptscotch
BuildArch:     noarch

%description doc
Contains documentations and example for scotch and ptscotch

###############################################################################

%if %{with mpich}
%package -n ptscotch-mpich
Summary:       PT-Scotch libraries compiled against mpich
BuildRequires: mpich-devel

%description -n ptscotch-mpich
Scotch is a software package for graph and mesh/hypergraph partitioning and
sparse matrix ordering. This sub-package provides parallelized scotch libraries
compiled with mpich.


%package -n ptscotch-mpich-devel
Summary:       Development libraries for PT-Scotch (mpich)
Requires:      pt%{name}-mpich%{?_isa} = %{version}-%{release}

%description -n ptscotch-mpich-devel
This package contains development libraries for PT-Scotch, compiled against
mpich.


%if %{with metis}
%package -n ptscotch-mpich-devel-parmetis
Summary:       Parmetis compatibility header
Requires:      pt%{name}-mpich-devel%{?_isa} = %{version}-%{release}

%description -n ptscotch-mpich-devel-parmetis
This header is a drop-in replacement for the original parmetis.h header
to build against the scotch.
%endif
%endif

###############################################################################

%if %{with openmpi}
%package ptscotch-openmpi%{openmpinumversion}
Summary:       PT-Scotch libraries compiled against openmpi
BuildRequires: openmpi-gcc-devel = %{openmpiversion}

%description ptscotch-openmpi%{openmpinumversion}
Scotch is a software package for graph and mesh/hypergraph partitioning and
sparse matrix ordering. This sub-package provides parallelized scotch libraries
compiled with openmpi.


%package ptscotch-openmpi%{openmpinumversion}-devel
Summary:       Development libraries for PT-Scotch (openmpi)
Requires:      %{name}-ptscotch-openmpi%{openmpinumversion}%{?_isa} = %{version}-%{release}

%description ptscotch-openmpi%{openmpinumversion}-devel
This package contains development libraries for PT-Scotch, compiled against
openmpi.


%if %{with metis}
%package ptscotch-openmpi%{openmpinumversion}-devel-parmetis
Summary:       Parmetis compatibility header
Requires:      %{name}-ptscotch-openmpi%{openmpinumversion}-devel%{?_isa} = %{version}-%{release}

%description ptscotch-openmpi%{openmpinumversion}-devel-parmetis
This header is a drop-in replacement for the original parmetis.h header
to build against the scotch.
%endif
%endif


###############################################################################

%prep
%autosetup -N -n %{rname}-v%{version}

# Convert the license files to utf8
for file in doc/CeCILL-C_V1-en.txt doc/CeCILL-C_V1-fr.txt; do
    iconv -f iso8859-1 -t utf-8 $file > $file.conv && mv -f $file.conv $file
done


%build
%define _vpath_builddir %{_target_platform}
%cmake -DBUILD_PTSCOTCH=OFF \
    -DCOMMON_PTHREAD:BOOL=ON \
    -DSCOTCH_PTHREAD:BOOL=ON \
    -DCOMMON_PTHREAD_AFFINITY_LINUX:BOOL=ON \
%if %{with metis}
    -DBUILD_LIBSCOTCHMETIS=ON \
    -DSCOTCH_METIS_VERSION=5 \
%else
    -DBUILD_LIBSCOTCHMETIS=OFF \
%endif
    -DCMAKE_INSTALL_BINDIR=%{topdir}/bin \
    -DCMAKE_INSTALL_LIBDIR=%{topdir}/%{_lib} \
    -DCMAKE_INSTALL_INCLUDEDIR=%{topdir}/include/scotch \
%cmake_build

%if %{with mpich}
%{_mpich_load}
%define _vpath_builddir %{_target_platform}-mpich
%cmake -DBUILD_PTSCOTCH=ON \
    -DCOMMON_PTHREAD:BOOL=ON \
    -DSCOTCH_PTHREAD:BOOL=ON \
    -DCOMMON_PTHREAD_AFFINITY_LINUX:BOOL=ON \
%if %{with metis}
    -DBUILD_LIBSCOTCHMETIS=ON \
    -DSCOTCH_PARMETIS_VERSION=3 \
%else
    -DBUILD_LIBSCOTCHMETIS=OFF \
%endif
    -DCMAKE_INSTALL_BINDIR=$MPI_BIN \
    -DCMAKE_INSTALL_LIBDIR=$MPI_LIB \
    -DCMAKE_INSTALL_INCLUDEDIR=$MPI_INCLUDE/scotch
%cmake_build
%{_mpich_unload}
%endif

%if %{with openmpi}
%{_openmpi_load}
%define _vpath_builddir %{_target_platform}-openmpi
%cmake -DBUILD_PTSCOTCH=ON \
    -DCOMMON_PTHREAD:BOOL=ON \
    -DSCOTCH_PTHREAD:BOOL=ON \
    -DCOMMON_PTHREAD_AFFINITY_LINUX:BOOL=ON \
%if %{with metis}
    -DBUILD_LIBSCOTCHMETIS=ON \
    -DSCOTCH_PARMETIS_VERSION=3 \
%else
    -DBUILD_LIBSCOTCHMETIS=OFF \
%endif
    -DCMAKE_INSTALL_BINDIR=%{topdiropenmpi}/bin \
    -DCMAKE_INSTALL_LIBDIR=%{topdiropenmpi}/%{_lib} \
    -DCMAKE_INSTALL_INCLUDEDIR=%{topdiropenmpi}/include/scotch
%cmake_build
%{_openmpi_unload}
%endif


%install
%define _vpath_builddir %{_target_platform}
%cmake_install

%if %{with metis}
# Default to the v5 API for the metis compat library
ln -s libscotchmetisv5.so %{buildroot}%{topdir}/%{_lib}/libscotchmetis.so
# Rename include files to avoid conflicts with original Metis
mv %{buildroot}%{topdir}/include/scotch/metis.h %{buildroot}%{topdir}/include/scotch/scotchmetis.h
mv %{buildroot}%{topdir}/include/scotch/metisf.h %{buildroot}%{topdir}/include/scotch/scotchmetisf.h
%endif
mkdir -p %{buildroot}%{topdir}/share/
cp -ar %{buildroot}%{_mandir} %{buildroot}%{topdir}/share/

##############
%if %{with mpich}
%{_mpich_load}
%define _vpath_builddir %{_target_platform}-mpich
%cmake_install

%if %{with metis}
# Default to the v5 API for the metis compat library
ln -s libscotchmetisv5.so %{buildroot}$MPI_LIB/libscotchmetis.so
# Only the ParMeTiS v3 API is available
ln -s libptscotchparmetisv3.so %{buildroot}$MPI_LIB/libparmetis.so
ln -s libptscotchparmetisv3.so %{buildroot}$MPI_LIB/libptscotchparmetis.so
# Rename include files to avoid conflicts with original Metis
mv %{buildroot}$MPI_INCLUDE/scotch/metis.h %{buildroot}$MPI_INCLUDE/scotch/scotchmetis.h
mv %{buildroot}$MPI_INCLUDE/scotch/metisf.h %{buildroot}$MPI_INCLUDE/scotch/scotchmetisf.h
%endif
%{_mpich_unload}
%endif
################

################
%if %{with openmpi}
%{_openmpi_load}
%define _vpath_builddir %{_target_platform}-openmpi
%cmake_install

%if %{with metis}
# Default to the v5 API for the metis compat library
ln -s libscotchmetisv5.so %{buildroot}%{topdiropenmpi}/%{_lib}/libscotchmetis.so
# Only the ParMeTiS v3 API is available
ln -s libptscotchparmetisv3.so %{buildroot}%{topdiropenmpi}/%{_lib}/libparmetis.so
ln -s libptscotchparmetisv3.so %{buildroot}%{topdiropenmpi}/%{_lib}/libptscotchparmetis.so
# Rename include files to avoid conflicts with original Metis
mv %{buildroot}%{topdiropenmpi}/include/scotch/metis.h %{buildroot}%{topdiropenmpi}/include/scotch/scotchmetis.h
mv %{buildroot}%{topdiropenmpi}/include/scotch/metisf.h %{buildroot}%{topdiropenmpi}/include/scotch/scotchmetisf.h
%endif
%{_openmpi_unload}
%endif
mkdir -p %{buildroot}%{topdiropenmpi}/share
cp -ar %{buildroot}%{_mandir} %{buildroot}%{topdiropenmpi}/share/
##################

# Don't install executables
#rm -f %{buildroot}%{_bindir}/*
#rm -f %{buildroot}%{_libdir}/mpich/bin/*
#rm -f %{buildroot}%{_libdir}/openmpi/bin/*
rm -rf %{buildroot}%{_mandir}/*

installmodule() {
D=$1
shift
M=%{buildroot}%{modulefile_path_top}/$1
case $1 in
        openmpi*)
                PREREQ="prereq openmpi"
                ;;
        *)
                PREREQ=""
                ;;
esac
shift
mkdir -p $M
cat >> $M/%{version} <<ENDMODULE
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# %{name} rpm).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds %{rname} %{version} $@ to various paths"
}

module-whatis   "Sets up %{rname} %{version} $@ in your environment"

prepend-path PATH "${D}/bin"
prepend-path LD_LIBRARY_PATH "${D}/%{_lib}"
prepend-path LIBRARY_PATH "${D}/%{_lib}"
prepend-path MANPATH "${D}/share/man"
setenv SCOTCH_HOME "$D"
append-path -d { } LDFLAGS "-L${D}/%{_lib}"
append-path -d { } INCLUDE "-I${D}/include"
append-path CPATH "${D}/include"
append-path -d { } FFLAGS "-I${D}/include"
append-path -d { } FCFLAGS "-I${D}/include"
append-path -d { } LOCAL_LDFLAGS "-L${D}/%{_lib}"
append-path -d { } LOCAL_INCLUDE "-I${D}/include"
append-path -d { } LOCAL_CFLAGS "-I${D}/include"
append-path -d { } LOCAL_FFLAGS "-I${D}/include"
append-path -d { } LOCAL_FCFLAGS "-I${D}/include"
append-path -d { } LOCAL_CXXFLAGS "-I${D}/include"
conflict scotch
$PREREQ
ENDMODULE
}
installmodule %{topdir} ""
installmodule %{topdiropenmpi} openmpi-%{openmpiversion} "with openmpi %{openmpiversion}"

###############################################################################



%check
%define _vpath_builddir %{_target_platform}
%ctest || :

%if %{with mpich}
%{_mpich_load}
%define _vpath_builddir %{_target_platform}-mpich
%ctest || :
%{_mpich_unload}
%endif

%if %{with openmpi}
%{_openmpi_load}
%define _vpath_builddir %{_target_platform}-openmpi
%ctest || :
%{_openmpi_unload}
%endif


%files
%license doc/CeCILL-C_V1-en.txt
%{topdir}/bin
%{topdir}/share
%dir %{toptopdir}
%dir %{topdir}
%dir %{topdir}/%{_lib}
%{topdir}/%{_lib}/libscotch.so.7*
%{topdir}/%{_lib}/libesmumps.so.7*
%{topdir}/%{_lib}/libscotcherr.so.7*
%{topdir}/%{_lib}/libscotcherrexit.so.7*
%if %{with metis}
%{topdir}/%{_lib}/libscotchmetisv3.so.7*
%{topdir}/%{_lib}/libscotchmetisv5.so.7*
%endif
%dir %{modulefile_path_top}
%{modulefile_path_top}/%{version}

%files devel
%dir %{topdir}/include
%dir %{topdir}/include/scotch
%{topdir}/include/scotch/scotch.h
%{topdir}/include/scotch/scotchf.h
%{topdir}/include/scotch/esmumps.h
%{topdir}/%{_lib}/libesmumps.so
%{topdir}/%{_lib}/libscotch.so
%{topdir}/%{_lib}/libscotcherr.so
%{topdir}/%{_lib}/libscotcherrexit.so
%if %{with metis}
%{topdir}/%{_lib}/libscotchmetisv3.so
%{topdir}/%{_lib}/libscotchmetisv5.so
%endif
%dir %{topdir}/%{_lib}/cmake
%dir %{topdir}/%{_lib}/cmake/scotch/
%{topdir}/%{_lib}/cmake/scotch/esmumpsTargets*
%{topdir}/%{_lib}/cmake/scotch/SCOTCH*
%{topdir}/%{_lib}/cmake/scotch/scotchTargets*
%{topdir}/%{_lib}/cmake/scotch/scotcherrTargets*
%{topdir}/%{_lib}/cmake/scotch/scotcherrexitTargets*

%if %{with metis}
%files devel-metis
%dir %{topdir}/include/scotch
%{topdir}/include/scotch/scotchmetis.h
%{topdir}/include/scotch/scotchmetisf.h
%{topdir}/%{_lib}/libscotchmetis.so
%{topdir}/%{_lib}/cmake/scotch/scotchmetisTargets*
%endif

%files doc
%license doc/CeCILL-C_V1-en.txt
%doc doc/*.pdf
%doc doc/scotch_example.f

%if %{with mpich}
%files -n ptscotch-mpich
%license doc/CeCILL-C_V1-en.txt
%{_libdir}/mpich/lib/libesmumps.so.7*
%{_libdir}/mpich/lib/libscotch.so.7*
%{_libdir}/mpich/lib/libscotcherr.so.7*
%{_libdir}/mpich/lib/libscotcherrexit.so.7*
%{_libdir}/mpich/lib/libptscotch.so.7*
%{_libdir}/mpich/lib/libptesmumps.so.7*
%{_libdir}/mpich/lib/libptscotcherr.so.7*
%{_libdir}/mpich/lib/libptscotcherrexit.so.7*
%if %{with metis}
%{_libdir}/mpich/lib/libscotchmetisv3.so.7*
%{_libdir}/mpich/lib/libscotchmetisv5.so.7*
%{_libdir}/mpich/lib/libptscotchparmetisv3.so.7*
%endif

%files -n ptscotch-mpich-devel
%dir %{_includedir}/mpich*/scotch
%{_includedir}/mpich*/scotch/ptscotch.h
%{_includedir}/mpich*/scotch/ptscotchf.h
%{_includedir}/mpich*/scotch/scotch.h
%{_includedir}/mpich*/scotch/scotchf.h
%{_includedir}/mpich*/scotch/esmumps.h
%{_libdir}/mpich/lib/libesmumps.so
%{_libdir}/mpich/lib/libscotch.so
%{_libdir}/mpich/lib/libscotcherr.so
%{_libdir}/mpich/lib/libscotcherrexit.so
%{_libdir}/mpich/lib/libptesmumps.so
%{_libdir}/mpich/lib/libptscotch.so
%{_libdir}/mpich/lib/libptscotcherr.so
%{_libdir}/mpich/lib/libptscotcherrexit.so
%if %{with metis}
%{_libdir}/mpich/lib/libscotchmetisv3.so
%{_libdir}/mpich/lib/libscotchmetisv5.so
%{_libdir}/mpich/lib/libptscotchparmetisv3.so
%endif
%dir %{_libdir}/mpich/lib/cmake/scotch/
%{_libdir}/mpich/lib/cmake/scotch/ptesmumpsTargets*
%{_libdir}/mpich/lib/cmake/scotch/SCOTCHConfig.cmake
%{_libdir}/mpich/lib/cmake/scotch/SCOTCHConfigVersion.cmake
%{_libdir}/mpich/lib/cmake/scotch/esmumpsTargets*
%{_libdir}/mpich/lib/cmake/scotch/ptscotchTargets*
%{_libdir}/mpich/lib/cmake/scotch/ptscotcherrTargets*
%{_libdir}/mpich/lib/cmake/scotch/ptscotcherrexitTargets*
%{_libdir}/mpich/lib/cmake/scotch/scotchTargets*
%{_libdir}/mpich/lib/cmake/scotch/scotcherrTargets*
%{_libdir}/mpich/lib/cmake/scotch/scotcherrexitTargets*

%if %{with metis}
%files -n ptscotch-mpich-devel-parmetis
%dir %{_includedir}/mpich*/scotch
%{_includedir}/mpich*/scotch/scotchmetis.h
%{_includedir}/mpich*/scotch/scotchmetisf.h
%{_includedir}/mpich*/scotch/parmetis.h
%{_libdir}/mpich/lib/libparmetis.so
%{_libdir}/mpich/lib/libptscotchparmetis.so
%{_libdir}/mpich/lib/libscotchmetis.so
%{_libdir}/mpich/lib/cmake/scotch/ptscotchparmetisTargets*
%{_libdir}/mpich/lib/cmake/scotch/scotchmetisTargets*
%endif
%endif


%if %{with openmpi}
%files ptscotch-openmpi%{openmpinumversion}
%license doc/CeCILL-C_V1-en.txt
%{topdiropenmpi}/bin
%{topdiropenmpi}/share
%dir %{toptopdiropenmpi}
%dir %{topdiropenmpi}
%dir %{topdiropenmpi}/%{_lib}
%{topdiropenmpi}/%{_lib}/libesmumps.so.7*
%{topdiropenmpi}/%{_lib}/libscotch.so.7*
%{topdiropenmpi}/%{_lib}/libscotcherr.so.7*
%{topdiropenmpi}/%{_lib}/libscotcherrexit.so.7*
%{topdiropenmpi}/%{_lib}/libptscotch.so.7*
%{topdiropenmpi}/%{_lib}/libptesmumps.so.7*
%{topdiropenmpi}/%{_lib}/libptscotcherr.so.7*
%{topdiropenmpi}/%{_lib}/libptscotcherrexit.so.7*
%if %{with metis}
%{topdiropenmpi}/%{_lib}/libscotchmetisv3.so.7*
%{topdiropenmpi}/%{_lib}/libscotchmetisv5.so.7*
%{topdiropenmpi}/%{_lib}/libptscotchparmetisv3.so.7*
%endif
%dir %{modulefile_path_top}
%dir %{modulefile_path_top}/openmpi-%{openmpiversion}
%{modulefile_path_top}/openmpi-%{openmpiversion}/%{version}

%files ptscotch-openmpi%{openmpinumversion}-devel
%dir %{topdiropenmpi}/include
%dir %{topdiropenmpi}/include/scotch
%{topdiropenmpi}/include/scotch/ptscotch.h
%{topdiropenmpi}/include/scotch/ptscotchf.h
%{topdiropenmpi}/include/scotch/scotch.h
%{topdiropenmpi}/include/scotch/scotchf.h
%{topdiropenmpi}/include/scotch/esmumps.h
%{topdiropenmpi}/%{_lib}/libesmumps.so
%{topdiropenmpi}/%{_lib}/libscotch.so
%{topdiropenmpi}/%{_lib}/libscotcherr.so
%{topdiropenmpi}/%{_lib}/libscotcherrexit.so
%{topdiropenmpi}/%{_lib}/libptesmumps.so
%{topdiropenmpi}/%{_lib}/libptscotch.so
%{topdiropenmpi}/%{_lib}/libptscotcherr.so
%{topdiropenmpi}/%{_lib}/libptscotcherrexit.so
%if %{with metis}
%{topdiropenmpi}/%{_lib}/libscotchmetisv3.so
%{topdiropenmpi}/%{_lib}/libscotchmetisv5.so
%{topdiropenmpi}/%{_lib}/libptscotchparmetisv3.so
%endif
%dir %{topdiropenmpi}/%{_lib}/cmake
%dir %{topdiropenmpi}/%{_lib}/cmake/scotch/
%{topdiropenmpi}/%{_lib}/cmake/scotch/ptesmumpsTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/SCOTCHConfig.cmake
%{topdiropenmpi}/%{_lib}/cmake/scotch/SCOTCHConfigVersion.cmake
%{topdiropenmpi}/%{_lib}/cmake/scotch/esmumpsTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/ptscotchTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/ptscotcherrTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/ptscotcherrexitTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/scotchTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/scotcherrTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/scotcherrexitTargets*

%if %{with metis}
%files ptscotch-openmpi%{openmpinumversion}-devel-parmetis
%dir %{topdiropenmpi}/include/scotch
%{topdiropenmpi}/include/scotch/scotchmetis.h
%{topdiropenmpi}/include/scotch/scotchmetisf.h
%{topdiropenmpi}/include/scotch/parmetis.h
%{topdiropenmpi}/%{_lib}/libparmetis.so
%{topdiropenmpi}/%{_lib}/libptscotchparmetis.so
%{topdiropenmpi}/%{_lib}/libscotchmetis.so
%{topdiropenmpi}/%{_lib}/cmake/scotch/ptscotchparmetisTargets*
%{topdiropenmpi}/%{_lib}/cmake/scotch/scotchmetisTargets*
%endif
%endif


%changelog
* Sat Dec 07 2024 Sandro Mani <manisandro@gmail.com> - 7.0.6-1
- Update to 7.0.6

* Wed Aug 14 2024 Sandro Mani <manisandro@gmail.com> - 7.0.5-1
- Update to 7.0.5

* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu May 02 2024 Sandro Mani <manisandro@gmail.com> - 7.0.5-4
- Fix libscotcherr, libscotcherrexit which should not be in -devel

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Oct 29 2023 Orion Poplawski <orion@nwra.com> - 7.0.5-2
- Rebuild for openmpi 5.0.0, drops support for i686

* Wed Aug 16 2023 Sandro Mani <manisandro@gmail.com> - 7.0.5-1
- Update to 7.0.5

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 7.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Apr 13 2023 Antonio Trande <sagitter@fedoraproject.org> - 7.0.3-2
- Undefine _ld_as_needed

* Thu Apr 13 2023 Antonio Trande <sagitter@fedoraproject.org> - 7.0.3-1
- Update to 7.0.3
- Patch0 updated
- Rename internal Metis include files to avoid conflicts

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Nov 13 2021 Sandro Mani <manisandro@gmail.com> - 6.1.2-1
- Update to 6.1.2

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Thu Jun 24 2021 Sandro Mani <manisandro@gmail.com> - 6.1.1-1
- Update to 6.1.1

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Sep 08 2020 Sandro Mani <manisandro@gmail.coM> - 6.1.0-1
- Update to 6.1.0

* Wed Sep 02 2020 Sandro Mani <manisandro@gmail.com> - 6.0.10-1
- Update to 6.0.10

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Nov 05 2019 Sandro Mani <manisandro@gmail.com> - 6.0.9-1
- Update to 6.0.9

* Tue Aug 27 2019 Sandro Mani <manisandro@gmail.com> - 6.0.8-1
- Update to 6.0.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon May 20 2019 Sandro Mani <manisandro@gmail.com> - 6.0.7-1
- Update to 6.0.7

* Fri Apr 12 2019 Jerry James <loganjerry@gmail.com> - 6.0.6-6
- Fix underlinked libraries (bz 1680315)
- Fix too-long description line
- Drop ancient obsoletes
- Add check script
- Fix undefined macros in man pages

* Thu Feb 14 2019 Orion Poplawski <orion@nwra.com> - 6.0.6-5
- Rebuild for openmpi 3.1.3

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Dec 16 2018 Orion Poplawski <orion@cnwra.com> - 6.0.6-3
- Make shared libraries link properly with -Wl,--as-needed

* Sat Dec 1 2018 Orion Poplawski <orion@cnwra.com> - 6.0.6-2
- Drop BR lzma, use xz for lzma support

* Mon Jul 16 2018 Sandro Mani <manisandro@gmail.com> - 6.0.6-1
- Update to 6.0.6

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Feb 12 2018 Sandro Mani <manisandro@gmail.com> - 6.0.5-1
- Update to 6.0.5

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.4-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.4-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.4-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Oct 27 2016 Sandro Mani <manisandro@gmail.com> - 6.0.4-13
- Drop -DSCOTCH_PTHREAD (#1386707)

* Mon Oct 24 2016 Dan Horák <dan[at]danny.cz> - 6.0.4-12
- drop ExcludeArch

* Fri Oct 21 2016 Orion Poplawski <orion@cora.nwra.com> - 6.0.4-11
- Rebuild for openmpi 2.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 6.0.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 22 2016 Sandro Mani <manisandro@gmail.com> - 6.0.4-9
- Install parmetis.h in separate package

* Tue Dec 01 2015 Than Ngo <than@redhat.com> - 6.0.4-8
- ExcludeArch: s390 s390x

* Thu Nov 26 2015 Dave Love <loveshack@fedoraproject.org> - 6.0.4-7
- Install parmetis.h
- Conditionalize %%license and %%__global_ldflags

* Tue Sep 15 2015 Orion Poplawski <orion@cora.nwra.com> - 6.0.4-6
- Rebuild for openmpi 1.10.0

* Sat Aug 15 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 6.0.4-5
- Rebuild for MPI provides

* Sun Jul 26 2015 Sandro Mani <manisandro@gmail.com> - 6.0.4-4
- Rebuild for RPM MPI Requires Provides Change

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun May  3 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 6.0.4-2
- Rebuild for changed mpich

* Sat Mar 14 2015 Sandro Mani <manisandro@gmail.com> - 6.0.4-1
- Update to 6.0.4

* Thu Mar 12 2015 Sandro Mani <manisandro@gmail.com> - 6.0.3-4
- Rebuild (mpich)

* Mon Dec 01 2014 Sandro Mani <manisandro@gmail.com> - 6.0.3-2
- Build esmumps

* Wed Nov 05 2014 Sandro Mani <manisandro@gmail.com> - 6.0.3-1
- Update to 6.0.3

* Mon Sep 22 2014 Sandro Mani <manisandro@gmail.com> - 6.0.1-1
- Update to 6.0.1

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 08 2014 Sandro Mani <manisandro@gmail.com> - 6.0.0-8
- Rework specfile

* Sat Jul 05 2014 Sandro Mani <manisandro@gmail.com> - 6.0.0-7
- Fix under-linked libraries (#1098680)

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Feb 27 2014 Deji Akingunola <dakingun@gmail.com> - 6.0.0-5
- Slightly modified Erik Zeek spec re-write (See 2012-10-08 below)
- Rename mpich and openmpi subpackages as ptscotch-(mpich/openmpi) (Laurence Mcglashan)

* Mon Feb 24 2014 Deji Akingunola <dakingun@gmail.com> - 6.0.0-4
- Rebuild for mpich-3.1

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 21 2013 Deji Akingunola <dakingun@gmail.com> - 6.0.0-2
- Rename mpich2 sub-packages to mpich and rebuild for mpich-3.0

* Thu Jun 13 2013 Deji Akingunola <dakingun@gmail.com> - 6.0.0-1
- Update to 6.0.0
- Configured to run with 2 threads (for now)
- Install the headers in arch-dependent sub-directories

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.12-2.b
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Nov 17 2012 Deji Akingunola <dakingun@gmail.com> - 5.1.12-1.b
- Update to 5.1.12b

* Mon Oct 08 2012 Erik Zeek <eczeek@sandia.gov> - 5.1.11-4
- Use internal build machinery to build shared libraries.
- A bunch of MPI love.
-   Install Mpich2 libraries in the proper path.
-   Provide Mpich2 and OpenMPI libraries.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Mar 29 2011 Deji Akingunola <dakingun@gmail.com> - 5.1.11-1
- Update to 5.1.11

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.10b-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Oct 19 2010 Deji Akingunola <dakingun@gmail.com> - 5.1.10b-1
- Update to 5.1.10b

* Thu Aug 12 2010 Deji Akingunola <dakingun@gmail.com> - 5.1.9-1
- Update to 5.1.9
- No more static builds

* Tue Apr 27 2010 Deji Akingunola <dakingun@gmail.com> - 5.1.8-1
- Update to 5.1.8

* Wed Nov 04 2009 Deji Akingunola <dakingun@gmail.com> - 5.1.7-2
- Fix the Source url

* Sun Sep 20 2009 Deji Akingunola <dakingun@gmail.com> - 5.1.7-1
- Update to 5.1.7
- Put the library under libdir

* Thu Jun 11 2009 Deji Akingunola <dakingun@gmail.com> - 5.1.6-3
- Further spec fixes from package review (convert license files to utf8)
- Prefix binaries and their corresponding manpages with scotch_ .
- Link in appropriates libraries when creating shared libs

* Thu Jun 04 2009 Deji Akingunola <dakingun@gmail.com> - 5.1.6-2
- Add zlib-devel as BR

* Wed May 13 2009 Deji Akingunola <dakingun@gmail.com> - 5.1.6-1
- Update to 5.1.6

* Fri Nov 21 2008 Deji Akingunola <dakingun@gmail.com> - 5.1.2-1
- Update to 5.1.2

* Fri Sep 19 2008 Deji Akingunola <dakingun@gmail.com> - 5.1.1-1
- initial package creation
